@@ -17,7 +17,7 @@
 
 package Lemonldap::NG::Manager::Build::Tree;
 
-our $VERSION = '2.0.10';
+our $VERSION = '2.0.12';
 
 # TODO: Missing:
 #  * activeTimer
@@ -79,6 +79,7 @@ sub tree {
                                         'portalRequireOldPassword',
                                         'hideOldPassword',
                                         'mailOnPasswordChange',
+                                        'portalEnablePasswordDisplay',
                                     ]
                                 },
                                 {
@@ -144,8 +145,8 @@ sub tree {
                             title => 'choiceParams',
                             help  => 'authchoice.html',
                             nodes => [
-                                'authChoiceParam', 'authChoiceModules',
-                                'authChoiceAuthBasic'
+                                'authChoiceParam',     'authChoiceModules',
+                                'authChoiceAuthBasic', 'authChoiceFindUser'
                             ]
                         },
                         {
@@ -621,13 +622,32 @@ sub tree {
                         {
                             title => 'portalServers',
                             help  => 'portalservers.html',
-                            form  => 'simpleInputContainer',
                             nodes => [
-                                'wsdlServer',         'restExportSecretKeys',
-                                'restClockTolerance', 'restSessionServer',
-                                'restConfigServer',   'restAuthServer',
-                                'restPasswordServer', 'soapSessionServer',
-                                'soapConfigServer',   'exportedAttr',
+                                'exportedAttr',
+                                {
+                                    title => 'restServices',
+                                    help  => 'portalservers.html#REST',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'restSessionServer',
+                                        'restConfigServer',
+                                        'restAuthServer',
+                                        'restPasswordServer',
+                                        'restExportSecretKeys',
+                                        'restClockTolerance',
+                                    ]
+                                },
+                                {
+                                    title => 'soapServices',
+                                    help =>
+                                      'portalservers.html#SOAP_(deprecated)',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'soapSessionServer',
+                                        'soapConfigServer',
+                                        'wsdlServer',
+                                    ]
+                                },
                             ]
                         },
                         {
@@ -763,15 +783,29 @@ sub tree {
                                 'checkUser',
                                 'checkUserIdRule',
                                 'checkUserUnrestrictedUsersRule',
-                                'checkUserHiddenAttributes',
                                 'checkUserSearchAttributes',
-                                'checkUserDisplayComputedSession',
-                                'checkUserDisplayEmptyHeaders',
-                                'checkUserDisplayEmptyValues',
-                                'checkUserDisplayPersistentInfo',
-                                'checkUserHiddenHeaders'
+                                'checkUserHiddenAttributes',
+                                'checkUserHiddenHeaders',
+                                {
+                                    title => 'checkUserDisplay',
+                                    help  => 'checkuser.html#configuration',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'checkUserDisplayComputedSession',
+                                        'checkUserDisplayPersistentInfo',
+                                        'checkUserDisplayNormalizedHeaders',
+                                        'checkUserDisplayEmptyHeaders',
+                                        'checkUserDisplayEmptyValues',
+                                    ]
+                                },
                             ]
                         },
+                        {
+                            title => 'devOpsCheck',
+                            help  => 'checkdevops.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [ 'checkDevOps', 'checkDevOpsDownload' ],
+                        },
                         {
                             title => 'impersonation',
                             help  => 'impersonation.html',
@@ -782,7 +816,19 @@ sub tree {
                                 'impersonationUnrestrictedUsersRule',
                                 'impersonationHiddenAttributes',
                                 'impersonationSkipEmptyValues',
-                                'impersonationMergeSSOgroups',
+                                'impersonationMergeSSOgroups'
+                            ]
+                        },
+                        {
+                            title => 'findUsers',
+                            help  => 'finduser.html',
+                            nodes => [
+                                'findUser',
+                                'findUserWildcard',
+                                'findUserControl',
+                                'restFindUserDBUrl',
+                                'findUserSearchingAttributes',
+                                'findUserExcludingAttributes'
                             ]
                         },
                         {
@@ -834,13 +880,11 @@ sub tree {
                             nodes => [
                                 'totp2fActivation',
                                 'totp2fSelfRegistration',
+                                'totp2fUserCanRemoveKey',
                                 'totp2fIssuer',
                                 'totp2fInterval',
                                 'totp2fRange',
                                 'totp2fDigits',
-                                'totp2fDisplayExistingSecret',
-                                'totp2fUserCanChangeKey',
-                                'totp2fUserCanRemoveKey',
                                 'totp2fTTL',
                                 'totp2fAuthnLevel',
                                 'totp2fLabel',
@@ -865,12 +909,12 @@ sub tree {
                             nodes => [
                                 'yubikey2fActivation',
                                 'yubikey2fSelfRegistration',
+                                'yubikey2fUserCanRemoveKey',
                                 'yubikey2fClientID',
                                 'yubikey2fSecretKey',
                                 'yubikey2fNonce',
                                 'yubikey2fUrl',
                                 'yubikey2fPublicIDSize',
-                                'yubikey2fUserCanRemoveKey',
                                 'yubikey2fFromSessionAttribute',
                                 'yubikey2fTTL',
                                 'yubikey2fAuthnLevel',
@@ -937,6 +981,7 @@ sub tree {
                                 'sfRemovedNotifMsg',
                             ],
                         },
+                        'sfRegisterTimeout',
                     ]
                 },
                 {
@@ -984,6 +1029,14 @@ sub tree {
                                 'requireToken',
                                 'formTimeout',
                                 'tokenUseGlobalStorage',
+                                {
+                                    title => 'CrowdSecPlugin',
+                                    help  => 'crowdsec.html',
+                                    nodes => [
+                                        'crowdsec',    'crowdsecAction',
+                                        'crowdsecUrl', 'crowdsecKey',
+                                    ],
+                                },
                                 {
                                     title => 'bruteForceAttackProtection',
                                     help  => 'bruteforceprotection.html',
@@ -998,7 +1051,6 @@ sub tree {
                                 },
                                 'lwpOpts',
                                 'lwpSslOpts',
-
                                 {
                                     title => 'contentSecurityPolicy',
                                     help  => 'security.html#portal',
@@ -1270,10 +1322,11 @@ sub tree {
                             group => [
                                 'oidcServicePrivateKeySig',
                                 'oidcServicePublicKeySig',
+                                'oidcServiceKeyIdSig',
                             ],
                         },
-                        'oidcServiceKeyIdSig',
                         'oidcServiceAllowDynamicRegistration',
+                        'oidcServiceAllowOnlyDeclaredScopes',
                         'oidcServiceAllowAuthorizationCodeFlow',
                         'oidcServiceAllowImplicitFlow',
                         'oidcServiceAllowHybridFlow',
@@ -1302,6 +1355,7 @@ sub tree {
                 'casStorage',
                 'casStorageOptions',
                 'casAttributes',
+                'casStrictMatching',
 
             ]
         },
